@@ -21,24 +21,25 @@ import (
 	"io/ioutil"
 	"net/http"
 	"os"
+	"path/filepath"
 	"reflect"
 	"testing"
 )
 
 var testAuthHeader http.Header = http.Header{"Authorization": {"Basic YmFyOmJheg=="}}
 
-// mockHttpDoer defines a wrapper that allows returning a mocked response.
-type mockHttpDoer struct {
+// mockHTTPDoer defines a wrapper that allows returning a mocked response.
+type mockHTTPDoer struct {
 	doer func(req *http.Request) (resp *http.Response, err error)
 }
 
-func (m *mockHttpDoer) Do(req *http.Request) (resp *http.Response, err error) {
+func (m *mockHTTPDoer) Do(req *http.Request) (resp *http.Response, err error) {
 	return m.doer(req)
 }
 
-func fakeHttpOrHttpsGet(filename string, httpSuccess bool, httpsSuccess bool, httpErrorCode int, header http.Header) func(req *http.Request) (*http.Response, error) {
+func fakeHTTPOrHTTPSGet(filename string, httpSuccess bool, httpsSuccess bool, httpErrorCode int, header http.Header) func(req *http.Request) (*http.Response, error) {
 	return func(req *http.Request) (*http.Response, error) {
-		f, err := os.Open(filename)
+		f, err := os.Open(filepath.Join("testdata", filename))
 		if err != nil {
 			return nil, err
 		}
@@ -46,7 +47,7 @@ func fakeHttpOrHttpsGet(filename string, httpSuccess bool, httpsSuccess bool, ht
 		var resp *http.Response
 
 		if header != nil && !reflect.DeepEqual(req.Header, header) {
-			err = fmt.Errorf("fakeHttpOrHttpsGet: wrong header %v. Expected %v", req.Header, header)
+			err = fmt.Errorf("fakeHTTPOrHTTPSGet: wrong header %v. Expected %v", req.Header, header)
 			return nil, err
 		}
 
@@ -78,7 +79,7 @@ func fakeHttpOrHttpsGet(filename string, httpSuccess bool, httpsSuccess bool, ht
 				Body: ioutil.NopCloser(bytes.NewBufferString("")),
 			}
 		default:
-			err = errors.New("fakeHttpOrHttpsGet failed as requested")
+			err = errors.New("fakeHTTPOrHTTPSGet failed as requested")
 			return nil, err
 		}
 
@@ -86,7 +87,7 @@ func fakeHttpOrHttpsGet(filename string, httpSuccess bool, httpsSuccess bool, ht
 	}
 }
 
-func TestHttpsOrHTTP(t *testing.T) {
+func TestHTTPSOrHTTP(t *testing.T) {
 	tests := []struct {
 		name          string
 		insecure      InsecureOption
@@ -98,8 +99,8 @@ func TestHttpsOrHTTP(t *testing.T) {
 		{
 			"good-server",
 			InsecureNone,
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", true, true, 0, nil),
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", true, true, 0, nil),
 			},
 			"https://good-server?ac-discovery=1",
 			true,
@@ -107,9 +108,9 @@ func TestHttpsOrHTTP(t *testing.T) {
 		},
 		{
 			"good-server-no-tls",
-			InsecureTls,
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", true, true, 0, nil),
+			InsecureTLS,
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", true, true, 0, nil),
 			},
 			"https://good-server-no-tls?ac-discovery=1",
 			true,
@@ -118,8 +119,8 @@ func TestHttpsOrHTTP(t *testing.T) {
 		{
 			"file-not-found",
 			InsecureNone,
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", false, false, 404, nil),
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", false, false, 404, nil),
 			},
 			"",
 			false,
@@ -127,9 +128,9 @@ func TestHttpsOrHTTP(t *testing.T) {
 		},
 		{
 			"file-not-found-no-tls",
-			InsecureTls,
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", false, false, 404, nil),
+			InsecureTLS,
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", false, false, 404, nil),
 			},
 			"",
 			false,
@@ -138,8 +139,8 @@ func TestHttpsOrHTTP(t *testing.T) {
 		{
 			"completely-broken-server",
 			InsecureNone,
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", false, false, 0, nil),
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", false, false, 0, nil),
 			},
 			"",
 			false,
@@ -148,8 +149,8 @@ func TestHttpsOrHTTP(t *testing.T) {
 		{
 			"file-only-on-http",
 			InsecureNone, // do not accept fallback on http
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", true, false, 404, nil),
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", true, false, 404, nil),
 			},
 			"",
 			false,
@@ -157,9 +158,9 @@ func TestHttpsOrHTTP(t *testing.T) {
 		},
 		{
 			"file-only-on-http",
-			InsecureHttp, // accept fallback on http
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", true, false, 404, nil),
+			InsecureHTTP, // accept fallback on http
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", true, false, 404, nil),
 			},
 			"http://file-only-on-http?ac-discovery=1",
 			true,
@@ -167,9 +168,9 @@ func TestHttpsOrHTTP(t *testing.T) {
 		},
 		{
 			"https-server-is-down",
-			InsecureHttp, // accept fallback on http
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", true, false, 0, nil),
+			InsecureHTTP, // accept fallback on http
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", true, false, 0, nil),
 			},
 			"http://https-server-is-down?ac-discovery=1",
 			true,
@@ -178,8 +179,8 @@ func TestHttpsOrHTTP(t *testing.T) {
 		{
 			"coreos.com",
 			InsecureNone,
-			&mockHttpDoer{
-				doer: fakeHttpOrHttpsGet("myapp.html", false, true, 0, testAuthHeader),
+			&mockHTTPDoer{
+				doer: fakeHTTPOrHTTPSGet("meta01.html", false, true, 0, testAuthHeader),
 			},
 			"https://coreos.com?ac-discovery=1",
 			true,
@@ -189,7 +190,7 @@ func TestHttpsOrHTTP(t *testing.T) {
 
 	for i, tt := range tests {
 		httpDo = tt.do
-		httpDoInsecureTls = tt.do
+		httpDoInsecureTLS = tt.do
 		hostHeaders := map[string]http.Header{
 			tt.name: tt.authHeader,
 		}
